#!/usr/bin/env python3
"""
    prime_lister.py
    This program builds a list of primes.
    
    The general strategy is:
    1. Put the first prime in the list (2)
    2. Create an index called "prime_candidate" that starts at 3
       and will increase each time through a loop
    3. We'll check the "prime_candidate" to see if it's a prime
       by going through our list of primes. IF THE prime_candidate
       IS DIVISIBLE BY A PRIME, THEN THE CANDIDATE IS *NOT* A PRIME.
    4. If we get through the whole list of primes, however, and we
       haven't been able to divide any of them evenly into our 
       prime_candidate, then the prime_candidate IS prime and we
       should add it to the list of primes.
    5. Increment the value of prime_candidate and go to step 3.
    6. Keep on going until our list has the required number of primes

    @author Richard White
    @version 2016-04-19

"""

def main():

    # initialize list of primes
    primes = [2]
    print(primes[0]) # We'll print the primes as we go

    # initialize prime_candidate
    prime_candidate = 3

    # how many primes do we want to find?
    NUM_OF_PRIMES = 10000

    while len(primes) < NUM_OF_PRIMES:
        # assume it's a prime, but go through list to see if
        # if that's true or not
        is_prime = True
        for prime in primes:
            if prime_candidate % prime == 0:  # number divided evenly
                is_prime = False              # so it's not prime 
                break
        # Now that we're out of loop, see if it was prime or not
        # and add it to the list if it was
        if is_prime:
            print(prime_candidate)
            primes.append(prime_candidate)

        # Whether we found a prime or not, now we increment 
        # prime_candidate and check the next one
        prime_candidate = prime_candidate + 1

    # We're all done searching!
    print("All done!")


if __name__ == "__main__":
    main()
