Wordle
======

Game Description
----------------

The player has six tries to guess a secret 5-letter word. After each guess, the 5 letters of the guess are displayed on-screen and highlighted as follows:

1. letters from the guess that are in their correct position in the secret word are displayed in the guess in a green color
2. letters from the guess that are in the secret word but not in their correct location are displayed in the guess in a yellow color
3. letters from the guess that are not in the secret word are displayed in the guess in a red color

Additionally, after each turn all the letters of the alphabet are displayed below the guess, colored green according to the same rule as above, yellow (according to rule above), red (for all letters that have been guessed and that are not in the word), or white if they haven't yet been tried in a word.

Guesses that are not legal words are not allowed (and don't count in the six tries). 

After six tries, if the user hasn't guessed the word, the solution is presented to them.

The original Wordle game can be played online at  

        https://www.powerlanguage.co.uk/wordle/

Note that you can only play once per day. :)


Preliminary thinking
--------------------

This game is similar in some ways to Hangman, in which a secret word is progressively revealed. It's also similar to the game Mastermind, in that the hints that are given after a guess focus on indicating which parts of the solution are absolutely correct (a letter in the word in its correct position) and wich are partially correct (a letter in the word in an incorrect position).

Each turn a word guess and the secret word are compared, and clues provided by color coding the guessed word. We're going to need to know how to produce color text on the screen, and also develop some logic for comparing the two words so that we can provide the appropriate color for each letter.

Description of Program
----------------------

At the beginning, pick a 5-letter word from a wordlist that the user will try to guess. Set up a list to keep track of the guessed letters that are misses.
Then run a loop that has the user enter a guess, and displays that guess according to the color-rules given above.

Special Information
-------------------

Some interesting challenges in this assignment include:

1. Where do we get a decent list of 5-letter words, and how do we select a random word from that list for the user to guess?
2. What logical analysis do we use to color each letter in the guess?
3. How do we display each letter with the correct color?


General Outline of Program
--------------------------



    import random       

    class Bcolors(object):
        """
        Usage:
            print(Bcolors.RED + "Warning" + Bcolors.ENDC)
            From: http://stackoverflow.com/questions/287871/print-in-terminal-with-colors-using-python
        """
        # Define colors. Upper case versions are brighter
        white = '\033[97m'
        WHITE = '\033[1;97m'
        magenta = '\033[95m'
        MAGENTA = '\033[1;95m'
        violet = '\033[94m'
        VIOLET = '\033[1;94m'
        yellow = '\033[93m'
        green = '\033[92m'
        GREEN = '\033[1;92m'
        red = '\033[91m'
        magenta2 = '\033[35m'
        blue = '\033[34m'
        yellow2 = '\033[33m'
        green2 = '\033[32m'
        GREEN2 = '\033[1;32m'
        red = '\033[31m'
        cyan = '\033[36m'
        white = '\033[37m'
        ENDC = '\033[0m'

    def get_5_letter_words():
        """
        Open up a text file and get only the five-letter words, then
        return those as a list. These words are all uppercase, so be sure
        to convert input to upper().
        """
        
        # code here
        

    def get_new_guess(words):
        """
        Gets a guess, and checks the list of words to see if it's a legal
        word. Otherwise, they have to keep guessing. Returns a legal word
        once we've gotten it.
        """
        guess = input().upper()    # convert to uppercase
        while guess not in words:
            print("I'm sorry, that word is not a legal guess.")
            guess = input("Enter another guess: ").upper()
        return guess


    def display_result(guess, word, letter_fails):
        """compare the guess and the secret word letter by letter,
        and print the letters of the guess out with the correct colors,
        as indicated by the rules. Keep track of missed letters in the
        letter_fails list.
        Once the word has been printed out, go through and print out all
        the letters in the alphabet, with colors as required.
        """
        
        # code here
         
        
    
    
    def main():
        """A working main() program is given here. There are many ways
        to write this program, so feel free to experiment.
        """
        
        words = get_5_letter_words()
        # Some of the words in the Scrabble list are wack.
        word = words[random.randrange(len(words))]
        letter_fails = []
        guess = '_____'
        guess_number = 1
        while guess_number < 7 and guess != word:
            display_result(guess, word, letter_fails)
            print("Guess #" + str(guess_number), end=': ')
            guess = get_new_guess(words)
            guess_number += 1
        # game over, one way or the other
        display_result(guess, word, letter_fails)
        if guess == word:
            print("You got it! Congratulations!")
        else:
            print("I'm sorry, you're all out of guesses.")
            print("The word was " + word)
    
    if __name__ == "__main__":
        main()
