#!/usr/bin/env python2.7
"""
burbank_temperature.py
@author Richard White
@version 2015-03-07

Get the current temperature based on NOAA data

This program uses information from NOAA's website to read the file for BUR airport's weather, and then parses
that data to find the current temperature.

Programs that attempt to parse HTML data are notoriously hacky: they rely on a more-or-less consistent format
in that page. If the HTML formatting changes, this script has to be rewritten.
"""

import urllib   # Used to read webpage html

# identify the webpage we'll be reading from
remotefile = urllib.urlopen("http://w1.weather.gov/obhistory/KBUR.html")

# read in the entire contents of that page
# (We could read this in line by line, but we're going to end up parsing
#  through the whole thing anyway, so this is okay.)
completeFileContent = "".join(remotefile.readlines())

# look for the line that has the temperature we want
# It's the first temperature line, which I had to figure out by looking
# at the webpage's html code. You can do that either by using a browser
# to "View Source" for a page, or by looking through the value of 
# completeFileContent after this program reads it in.
start = completeFileContent.find('<tr align="center" bgcolor="#b0c4de"><th width="26">Max.</th><th width="26">Min.</th></tr><tr align="center" valign="top" bgcolor="#eeeeee">')

# The temperature is listed 6 data cells over, with each one ending in '</td>'
# Move the start location past those 6 cells and on to the seventh.
# Then we'll back up to find our data.
for i in range(7):
    start = completeFileContent.find('</td>', start + 1)

# We've identified the end of our data range...
stop = start

# Now, where is the beginning of our data range? 
# Back up a few characters to find the '>'
start = completeFileContent.find('>', stop - 5, stop) + 1

# Print out the characters with the current temperature
print "The temperature in Burbank is currently " + completeFileContent[start: stop] + " degrees Fahrenheit."


